package com.ruoyi.postCheck.service;

import java.util.List;

import com.ruoyi.postCheck.domain.PostChecked;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 岗检表管理Service接口
 *
 * @author csg
 * @date 2024-01-05
 */
public interface IPostCheckedService extends IService<PostChecked> {
    /**
     * 查询岗检表管理
     *
     * @param id 岗检表管理主键
     * @return 岗检表管理
     */
    public PostChecked selectPostCheckedById(Long id);

    /**
     * 查询岗检表管理列表
     *
     * @param postChecked 岗检表管理
     * @return 岗检表管理集合
     */
    public List<PostChecked> selectPostCheckedList(PostChecked postChecked);

    /**
     * 新增岗检表管理
     *
     * @param postChecked 岗检表管理
     * @return 结果
     */
    public int insertPostChecked(PostChecked postChecked);

    /**
     * 修改岗检表管理
     *
     * @param postChecked 岗检表管理
     * @return 结果
     */
    public int updatePostChecked(PostChecked postChecked);

    /**
     * 批量删除岗检表管理
     *
     * @param ids 需要删除的岗检表管理主键集合
     * @return 结果
     */
    public int deletePostCheckedByIds(Long[] ids);

    /**
     * 删除岗检表管理信息
     *
     * @param id 岗检表管理主键
     * @return 结果
     */
    public int deletePostCheckedById(Long id);
}
